@@ -10,6 +10,7 @@ from soco_cli.utils import (
     configure_logging,
     docs,
     error_and_exit,
+    logo,
     version,
 )
 
@@ -46,6 +47,8 @@ def main():
     # Parse the command line
     args = parser.parse_args()
 
+    configure_logging(args.log)
+
     if args.version:
         version()
         exit(0)
@@ -54,12 +57,14 @@ def main():
         docs()
         exit(0)
 
+    if args.logo:
+        logo()
+        exit(0)
+
     if args.check_for_update:
         print_update_status()
         exit(0)
 
-    configure_logging(args.log)
-
     # Create the Speakers object
     speaker_list = Speakers()
 
